/*
 * Guifications - The end all, be all, toaster popup plugin
 * Copyright (C) 2003-2004 Gary Kramlich
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef GF_STOCK_H
#define GF_STOCK_H

#define GF_STOCK_WINDOW_POSITION_NORTH_WEST "gf_window_north_west"
#define GF_STOCK_WINDOW_POSITION_NORTH_EAST "gf_window_north_east"
#define GF_STOCK_WINDOW_POSITION_SOUTH_WEST "gf_window_south_west"
#define GF_STOCK_WINDOW_POSITION_SOUTH_EAST "gf_window_south_east"
#define GF_STOCK_ITEM_ICON_SIZE_BIG "item_icon_size_big"
#define GF_STOCK_ITEM_ICON_SIZE_HUGE "item_icon_size_huge"
#define GF_STOCK_ITEM_ICON_SIZE_LARGE "item_icon_size_large"
#define GF_STOCK_ITEM_ICON_SIZE_LITTLE "item_icon_size_little"
#define GF_STOCK_ITEM_ICON_SIZE_NORMAL "item_icon_size_normal"
#define GF_STOCK_ITEM_ICON_SIZE_SMALL "item_icon_size_small"
#define GF_STOCK_ITEM_ICON_SIZE_TINY "item_icon_size_tiny"
#define GF_STOCK_ITEM_POSITION_CENTER "item_position_center"
#define GF_STOCK_ITEM_POSITION_EAST "item_position_east"
#define GF_STOCK_ITEM_POSITION_NORTH_EAST "item_position_north_east"
#define GF_STOCK_ITEM_POSITION_NORTH "item_position_north"
#define GF_STOCK_ITEM_POSITION_NORTH_WEST "item_position_north_west"
#define GF_STOCK_ITEM_POSITION_SOUTH_EAST "item_position_south_east"
#define GF_STOCK_ITEM_POSITION_SOUTH "item_position_south"
#define GF_STOCK_ITEM_POSITION_SOUTH_WEST "item_position_south_west"
#define GF_STOCK_ITEM_POSITION_WEST "item_position_west"
#define GF_STOCK_ITEM_TEXT_CLIPPING_ELLIPSIS_END "item_text_clipping_ellipsis_end"
#define GF_STOCK_ITEM_TEXT_CLIPPING_ELLIPSIS_MIDDLE "item_text_clipping_ellipsis_middle"
#define GF_STOCK_ITEM_TEXT_CLIPPING_ELLIPSIS_START "item_text_clipping_ellipsis_start"
#define GF_STOCK_ITEM_TEXT_CLIPPING_TRUNCATE "item_text_clipping_truncate"

G_BEGIN_DECLS

void gf_stock_init();
void gf_stock_uninit();

G_END_DECLS

#endif /* GF_STOCK_H */
